import com.nokia.meego 1.0
import QtQuick 1.1
import com.nokia.extras 1.1
import com.nokia.controlpanel 0.1
import org.coderus.GConf 1.0
import org.ancelad.Ambiance 1.0

Page {
    id: mainPage
    orientationLock: PageOrientation.LockPortrait

    Image {
        source: "/usr/share/themes/sailfish/meegotouch/images/common_backgrounds/480x854.png"
        }
		
    tools: ToolBarLayout {
            Image {
            source: "/usr/share/themes/sailfish/meegotouch/images/common_backgrounds/480x72.png"
            }
			
        Button {
            platformStyle: ButtonStyle {
            background: "images/m-toolbar-back.png"
            checkedBackground: "images/m-toolbar-back-pressed.png"
            pressedBackground: "images/m-toolbar-back-pressed.png"
            }                   
            text: ""
            anchors.left: parent.left
            width: 64
            height: 64
            onClicked: {
                        if (pageStack.depth > 1) {
                        pageStack.pop();
                    } else if (dcp.isStandalone) {
                        dcp.popupMainPageAlone();
                    } else {
                        Qt.quit();                   
	            }	
			}
	    }
		
		Button {
        platformStyle: ButtonStyle {
        background: "/usr/share/themes/sailfish/meegotouch/icons/icon-m-sailfish.png"
        checkedBackground: "images/m-toolbar-back-pressed.png"
        pressedBackground: "/usr/share/themes/sailfish/meegotouch/icons/icon-m-sailfish-pressed.png"
        }                   
        text: ""
        anchors.top: parent.top
        anchors.topMargin: 8
        anchors.right: parent.right
		anchors.rightMargin: 1
        width: 64
        height: 64
            onClicked: {
                pageStack.push(Qt.resolvedUrl("AboutPage.qml"))
			} 
        }		
    }
	
    GConf {
        id: gconf
    }

    Ambiance {
        id: ambiance
    }

    function iconApply(path) {
        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/launcher_options.sh", [path])
		banner.notify(qsTr("Done! Restart themedaemon."))
    }

    function backgroundApply(path) {
        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/apply_background.sh", [path])
		banner.notify(qsTr("Done! Restart themedaemon."))
    }
					
        Flickable {
        id: flickable
        anchors.fill: parent
        flickableDirection: Flickable.VerticalFlick
        contentHeight: content.height
		
        Column {		
        id: content
        width: parent.width	
		
		DcpPageTitle {
                x: 10		
                text: qsTr("Ambiance settings")
	    }
		
		Item {
		width: 1
		height: 10
		}
		
        Separator {
                title: qsTr("Ambiance presets")
                color: "white"
            }

            Repeater {
                id: ambiancePresets
                width: parent.width
                model: ambianceModel
                property string selectedValue: ""
                delegate: Item {
                    id: delegateItem

                    height: 64
                    anchors.left: parent.left
                    anchors.right: parent.right

                    MouseArea {
                        id: delegateMouseArea
                        anchors.fill: parent
                        onClicked: {
                            gconf.set("/apps/ancelad/ambiance", value)
                            var reply = ambiance.shell(value)
                            banner.notify(qsTr("Done! Restart themedaemon."))
                            ambiancePresets.selectedValue = value
                        }
                    }

                    Rectangle {
                        id: backgroundRect
                        anchors.fill: parent
                        color: ((value == ambiancePresets.selectedValue) || delegateMouseArea.pressed) ? "#60CCCCCC" : "transparent"
                    }

                    Label {
                        id: itemText
                        elide: Text.ElideRight
                        anchors.verticalCenter: delegateItem.verticalCenter
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.leftMargin: 16
                        anchors.rightMargin: 16
                        text: name
                    }
                }
            }
	        Separator {
                title: qsTr("Ambiance wallpaper")
                color: "white"
            }

            Row {

                width: parent.width
                anchors.horizontalCenter: parent.horizontalCenter

                Button {
                     platformStyle: ButtonStyle {
                         background: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg.png"
                         pressedBackground: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_pressed.png"
						 pressedTextColor: "#c8a955"
                       }
                    text: qsTr("Create")
                    anchors.left: parent.left
                    anchors.leftMargin: 39
                    width: 182
					height: 66
				    font.weight: Font.Light
				    font.pixelSize: 30
                    onClicked: {
					      pageStack.push(Qt.resolvedUrl("EffectsPage.qml"))
                    }
                }

                Button {
                     platformStyle: ButtonStyle {
                         background: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg.png"
                         pressedBackground: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_pressed.png"
						 pressedTextColor: "#c8a955"
                       }
                anchors.right: parent.right
                anchors.rightMargin: 39               
                    text: qsTr("Apply")
                    width: 182
					height: 66
				    font.weight: Font.Light
				    font.pixelSize: 30
                    onClicked: {
                    pageStack.push(Qt.resolvedUrl("Wallpapers.qml"))
                    //pageStack.currentPage.selected.connect(mainPage.backgroundApply)
                    }
                }
            }
			
            Separator {
                title: qsTr("Fine-tuning")
                color: "white"
            }

            SelectionItem {
                id: previewItem
                anchors.left: parent.left
                anchors.leftMargin: 16
                title: qsTr("Notifications preview (lockscreen)")
                model: previewModel
                onValueChosen: {
                    gconf.set("/apps/ancelad/preview", currentValue)
                    ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/notification_options.sh")
                    banner.notify(qsTr("Done! Restart themedaemon."))
                }
            }

            SelectionItem {
                id: avatarItem
                anchors.left: parent.left
                anchors.leftMargin: 16
                title: qsTr("Avatar settings (call interface)")
                model: avatarModel
                onValueChosen: {
                    gconf.set("/apps/ancelad/avatar", currentValue)
                    ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/avatar_options.sh")
                    banner.notify(qsTr("Done! Restart themedaemon."))
                }
            }
				
            SelectionItem {
                id: mthomeItem
                anchors.left: parent.left
                anchors.leftMargin: 16
                title: qsTr("Multitasking-window interface")
                model: mthomeModel
                onValueChosen: {
				    gconf.set("/apps/ancelad/multitaskwindow", currentValue)          
                    ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/close_icon.sh")
                    banner.notify(qsTr("Done! Restart homescreen."))
                }
            }

            SelectionItem {
                id: swypeItem
                anchors.left: parent.left
                anchors.leftMargin: 16
                title: qsTr("Swype-keyboard style")
                model: swypeModel
                onValueChosen: {
                    gconf.set("/apps/ancelad/swype", currentValue)
                    ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/swype_options.sh")
                    banner.notify(qsTr("Done! Restart themedaemon."))
                }
            }

            SelectionItem {
                id: keyboardItem
                anchors.left: parent.left
                anchors.leftMargin: 16
                title: qsTr("Keyboard style")
                model: keyboardModel
                onValueChosen: {
                    gconf.set("/apps/ancelad/keyboard", currentValue)
                    ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/keyboard_options.sh")
                    banner.notify(qsTr("Done! Restart themedaemon."))
                }
            }			
			
            SelectionItem {
                id: alarmItem
                anchors.left: parent.left
                anchors.leftMargin: 16
                title: qsTr("Alarm style")
                model: alarmModel
                onValueChosen: {
                    gconf.set("/apps/ancelad/alarm", currentValue)
                    ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/alarm_options.sh")
                    banner.notify(qsTr("Done! Restart themedaemon."))
                }
            }

            SelectionItem {
                id: analogclockItem
                anchors.left: parent.left
                anchors.leftMargin: 16
                title: qsTr("Analog-clock style")
                model: analogclockModel
                onValueChosen: {
                    gconf.set("/apps/ancelad/analog_clock", currentValue)
                    ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/analogclock.sh")
                    banner.notify(qsTr("Done! Restart themedaemon."))
                }
            }			
			
            SelectionItem {
                id: fasterItem
                anchors.left: parent.left
                anchors.leftMargin: 16
                title: qsTr("Faster transitions")
                model: fasterModel
                onValueChosen: {
                    gconf.set("/apps/ancelad/faster", currentValue)
                    ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/faster_options.sh")
                    banner.notify(qsTr("Done! Reboot your phone."))
                }
            }

			Separator {
                title: qsTr("Harmattan call-ui")
                color: "white"
            }
			
            Label {
                text: qsTr("Use Harmattan call-ui without buttons at the top and at the bottom of calling page. Only 'Large and Square avatar' option is available for this feature.")
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.right: parent.right
                anchors.rightMargin: 16
                horizontalAlignment: Text.AlignHRight
                wrapMode: Text.WordWrap        
		    }	
						
            MySwitch {
                id: calluiHarmattan
                anchors.right: parent.right
                onClicked: {
                        width: 64
                        height: 64
                    if (checked) {
					    gconf.set("/apps/ancelad/calluiHarmattan", "true")
                        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/calluiHarmattan.sh")
                        banner.notify(qsTr("Done! Restart themedaemon."))
                                            }
                    else {
					    gconf.set("/apps/ancelad/calluiHarmattan", "false")
                        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/calluiHarmattan.sh")
                        banner.notify(qsTr("Done! Restart themedaemon."))
                    }
                    gconf.set("/apps/ancelad/calluiHarmattan", checked)
                }
            }
			
			Separator {
                title: qsTr("Enable splashes")
                color: "white"
            }
			
            Label {
                text: qsTr("You can enable/disable splash-pictures for these apps: Gallery, Music, Facebook, Clock, Search, Office, Notes, Ovi Store, Ovi Music.")
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.right: parent.right
                anchors.rightMargin: 16
                horizontalAlignment: Text.AlignHRight
                wrapMode: Text.WordWrap        
		    }
			
            MySwitch {
                id: enableSplash
                anchors.right: parent.right
                onClicked: {
                        width: 64
                        height: 64
                    if (checked) {
					    gconf.set("/apps/ancelad/enableSplash", "true")
                        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/splash.sh")
                        banner.notify(qsTr("Done!"))
                        }
                    else {
					    gconf.set("/apps/ancelad/enableSplash", "false")
                        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/splash.sh")
                        banner.notify(qsTr("Done!"))
                    }
                    gconf.set("/apps/ancelad/enableSplash", checked)
                }
            }	
			
			Separator {
                title: qsTr("Dialpad buttons")
                color: "white"
            }
			
            Label {
                text: qsTr("Use rounded texture for pressed dialpad-buttons. Texture is square by default.")
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.right: parent.right
                anchors.rightMargin: 16
                horizontalAlignment: Text.AlignHRight
                wrapMode: Text.WordWrap        
		    }	
						
            MySwitch {
                id: roundDialpad
                anchors.right: parent.right
                onClicked: {
                        width: 64
                        height: 64
                    if (checked) {
					    gconf.set("/apps/ancelad/roundDialpad", "true")
                        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/round_dialpad.sh")
                        banner.notify(qsTr("Done! Restart themedaemon."))
                                            }
                    else {
					    gconf.set("/apps/ancelad/roundDialpad", "false")
                        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/round_dialpad.sh")
                        banner.notify(qsTr("Done! Restart themedaemon."))
                    }
                    gconf.set("/apps/ancelad/roundDialpad", checked)
                }
            }
			
			Separator {
                title: qsTr("Popup notifications")
                color: "white"
            }
			
            MySwitch {
                id: popupNotifications
                anchors.right: parent.right
                onClicked: {
                        width: 64
                        height: 64
                    if (checked) {
					    gconf.set("/desktop/meego/notifications/previews_enabled", "true")
                        banner.notify(qsTr("Done!"))
                                            }
                    else {
					    gconf.set("/desktop/meego/notifications/previews_enabled", "false")
                        banner.notify(qsTr("Done!"))
                    }
                    gconf.set("/desktop/meego/notifications/previews_enabled", checked)
                }
            }	
		
			Separator {
                title: qsTr("Hide 'Nothing open yet'")
                color: "white"
            }

            MySwitch {
                id: mthomeLabel
                anchors.right: parent.right
                onClicked: {
                        width: 64
                        height: 64
                    if (checked) {
					    gconf.set("/apps/ancelad/mthomeLabel", "true")
                        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/mthome_options.sh")
                        banner.notify(qsTr("Done! Restart homescreen."))
                                            }
                    else {
					    gconf.set("/apps/ancelad/mthomeLabel", "false")
                        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/mthome_options.sh")
                        banner.notify(qsTr("Done! Restart homescreen."))
                    }
                    gconf.set("/apps/ancelad/mthomeLabel", checked)
                }
            }
											
            Item {
                width: 1
                height: 16
            }
			
            Separator {
                color: "white"
                title: qsTr("Other settings")
            }

            Item {
                width: 1
                height: 16
            }
			
            Button {
                     platformStyle: ButtonStyle {
                         background: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_large.png"
                         pressedBackground: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_large_pressed.png"
						 pressedTextColor: "#c8a955"
                       }
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr("Lockscreen/LPS")
				width: 322
				height: 66
				font.weight: Font.Light
				font.pixelSize: 30
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("LockScreen.qml"))
                }
            }

            Button {
                     platformStyle: ButtonStyle {
                         background: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_large.png"
                         pressedBackground: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_large_pressed.png"
						 pressedTextColor: "#c8a955"
                       }
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr("Homescreen")
				width: 322
				height: 66
				font.weight: Font.Light
				font.pixelSize: 30
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("Homescreen.qml"))
                }
            }			
			
            Button {
                     platformStyle: ButtonStyle {
                         background: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg.png"
                         pressedBackground: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_pressed.png"
						 pressedTextColor: "#c8a955"
                       }
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr("Icons")
				width: 186
				height: 66
				font.weight: Font.Light
				font.pixelSize: 30
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("MainIcons.qml"))
                }
            }			
			
            Button {
                     platformStyle: ButtonStyle {
                         background: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg.png"
                         pressedBackground: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_pressed.png"
						 pressedTextColor: "#c8a955"
                       }
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr("Statusbar")
				width: 186
				height: 66
				font.weight: Font.Light
				font.pixelSize: 30
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("StatusBar.qml"))
                }
            }

            Button {
                     platformStyle: ButtonStyle {
                         background: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg.png"
                         pressedBackground: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_pressed.png"
						 pressedTextColor: "#c8a955"
                       }
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr("Folder")
				width: 186
				height: 66
				font.weight: Font.Light
				font.pixelSize: 30
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("Folder.qml"))
                }
            }
			
            Separator {
                color: "white"
                width: 520
            }
			
            Button {
                     platformStyle: ButtonStyle {
                         background: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_large.png"
                         pressedBackground: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_large_pressed.png"
						 pressedTextColor: "#c8a955"
                       }
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr("Restart themedaemon")
				width: 322
				height: 66
				font.weight: Font.Light
				font.pixelSize: 30
                onClicked: {
                    ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/restart_themedaemon.sh")
                }
            }

            Button {
                     platformStyle: ButtonStyle {
                         background: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_large.png"
                         pressedBackground: "/usr/share/themes/sailfish/meegotouch/images/button_bg/button_bg_large_pressed.png"
						 pressedTextColor: "#c8a955"
                       }
                anchors.horizontalCenter: parent.horizontalCenter
                text: qsTr("Restart homescreen")
				width: 322
				height: 66
				font.weight: Font.Light
				font.pixelSize: 30
                onClicked: {
                        ambiance.shell("/usr/share/themes/sailfish/meegotouch/.ambiance/scripts/restart_homescreen.sh")
                }
            }
		
            Item { //spacing
                width: 1
                height: 90
            }
        }
    }

    Component.onCompleted: {
        ambiancePresets.selectedValue = gconf.get("/apps/ancelad/ambiance")
        var availableAmbiances = ambiance.listAvailable()
        for (var i = 0; i < availableAmbiances.length; i++) {
            ambianceModel.append({ "name": availableAmbiances[i].name, "value": availableAmbiances[i].value })
        }
		popupNotifications.checked  = gconf.get("/desktop/meego/notifications/previews_enabled", false)
		mthomeLabel.checked  = gconf.get("/apps/ancelad/mthomeLabel", false)
        avatarItem.initialValue = gconf.get("/apps/ancelad/avatar")
        mthomeItem.initialValue = gconf.get("/apps/ancelad/multitaskwindow")
        previewItem.initialValue = gconf.get("/apps/ancelad/preview")
        swypeItem.initialValue = gconf.get("/apps/ancelad/swype")
	    keyboardItem.initialValue = gconf.get("/apps/ancelad/keyboard")
        fasterItem.initialValue = gconf.get("/apps/ancelad/faster")
        alarmItem.initialValue = gconf.get("/apps/ancelad/alarm")
		analogclockItem.initialValue = gconf.get("/apps/ancelad/analog_clock")
		roundDialpad.checked = gconf.get("/apps/ancelad/roundDialpad")
		calluiHarmattan.checked = gconf.get("/apps/ancelad/calluiHarmattan")
		enableSplash.checked = gconf.get("/apps/ancelad/enableSplash")
    }

    ListModel {
        id: ambianceModel
    }

    ListModel {
        id: analogclockModel
        Component.onCompleted: {
        	append({"name": qsTr("Sailfish-style"), "value": "sailfish"})
        	append({"name": qsTr("MeeGo-style"), "value": "meego"})
        }
    }
	
    ListModel {
        id: avatarModel
        Component.onCompleted: {
        	append({"name": qsTr("Large and square"), "value": "sailfish_large"})
        	append({"name": qsTr("Small and Square"), "value": "sailfish_small"})
        }
    }

    ListModel {
        id: mthomeModel
        Component.onCompleted: {
        	append({"name": qsTr("Close-icon in the center"), "value": "center"})
        	append({"name": qsTr("Close-icon at the bottom"), "value": "bottom"})
        }
    }

    ListModel {
        id: previewModel
        Component.onCompleted: {
        	append({"name": qsTr("Sailfish-style"), "value": "sailfish"})
        	append({"name": qsTr("MeeGo-style"), "value": "meego"})
        	append({"name": qsTr("Only icon"), "value": "icon"})
        }
    }

    ListModel {
        id: swypeModel
        Component.onCompleted: {
        	append({"name": qsTr("Sailfish-style"), "value": "sailfish_swype"})
        	append({"name": qsTr("MeeGo-style"), "value": "meego_swype"})
        }
    }

    ListModel {
        id: keyboardModel
        Component.onCompleted: {
        	append({"name": qsTr("Use keyboard from blanco"), "value": "blanco"})
        	append({"name": qsTr("Sailfish keyboard"), "value": "sailfish"})
        }
    }	
	
    ListModel {
        id: fasterModel
        Component.onCompleted: {
        	append({"name": qsTr("Enabled"), "value": "enabled"})
        	append({"name": qsTr("Disabled"), "value": "disabled"})
        }
    }

    ListModel {
        id: alarmModel
        Component.onCompleted: {
        	append({"name": qsTr("Sailfish-style"), "value": "sailfish"})
        	append({"name": qsTr("MeeGo-style"), "value": "meego"})
        }
    }

    ScrollDecorator {
        flickableItem: flickable
    }
}        